@@ -1,13 +1,13 @@
 use std::borrow::Borrow;
+use std::io::IsTerminal;
 
-pub use atty::Stream;
 use once_cell::sync::Lazy;
 
 use crate::delta_e::ciede2000;
 use crate::{Color, Lab};
 
 static ANSI_LAB_REPRESENTATIONS: Lazy<Vec<(u8, Lab)>> = Lazy::new(|| {
-    (16..255)
+    (16..=255)
         .map(|code| (code, Color::from_ansi_8bit(code).to_lab()))
         .collect()
 });
@@ -18,6 +18,20 @@ pub enum Mode {
     TrueColor,
 }
 
+#[derive(Debug)]
+pub struct UnknownColorModeError(pub String);
+
+impl Mode {
+    pub fn from_mode_str(mode_str: &str) -> Result<Option<Self>, UnknownColorModeError> {
+        match mode_str {
+            "24bit" | "truecolor" => Ok(Some(Mode::TrueColor)),
+            "8bit" => Ok(Some(Mode::Ansi8Bit)),
+            "off" => Ok(None),
+            value => Err(UnknownColorModeError(value.into())),
+        }
+    }
+}
+
 fn cube_to_8bit(code: u8) -> u8 {
     assert!(code < 6);
     match code {
@@ -256,7 +270,7 @@ pub fn get_colormode() -> Option<Mode> {
     }
 }
 
-#[derive(Debug, Clone, Copy)]
+#[derive(Default, Debug, Clone, Copy)]
 pub struct Brush {
     mode: Option<Mode>,
 }
@@ -266,13 +280,17 @@ impl Brush {
         Brush { mode }
     }
 
-    pub fn from_environment(stream: Stream) -> Self {
-        let mode = if atty::is(stream) {
-            get_colormode()
+    pub fn from_environment<T: IsTerminal>(stream: &T) -> Result<Self, UnknownColorModeError> {
+        let mode = if stream.is_terminal() {
+            let env_color_mode = std::env::var("PASTEL_COLOR_MODE").ok();
+            match env_color_mode.as_deref() {
+                Some(mode_str) => Mode::from_mode_str(mode_str)?,
+                None => get_colormode(),
+            }
         } else {
             None
         };
-        Brush { mode }
+        Ok(Brush { mode })
     }
 
     pub fn paint<S>(self, text: S, style: impl Into<Style>) -> String
@@ -347,6 +365,7 @@ mod tests {
     fn to_ansi_8bit_grays() {
         assert_eq!(232, Color::from_rgb(8, 8, 8).to_ansi_8bit());
         assert_eq!(242, Color::from_rgb(108, 108, 108).to_ansi_8bit());
+        assert_eq!(255, Color::from_rgb(238, 238, 238).to_ansi_8bit());
     }
 
     #[test]
